
# Iot Redis Cache Package Managament

This package contains important classes and threads for manage graph connections in containers

## Goal
Create a class which send signals when data is received in a specific channel.
